// c4Light.cpp: implementation of the c4Light class.
//
//////////////////////////////////////////////////////////////////////

#include "c4Light.h"

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

c4Light::c4Light()
{
 on = true;
}

c4Light::~c4Light()
{

}

/*
Compute apparent brightness.
Blend colors.
Apply bright to colors.

  Equation for brightness is from a textbook.
*/
c4PointC c4Light::Light(c4PointC vert)
{
	if(!on)
	{
		return vert;
	}
	c4PointC retval;
	float appb;
	float dis;

	//Step 1.
	dis = Distance(vert);
	//Now to see whether its within the radius of the light.
	if(dis > size)
	{
		return vert;
	}
	//Trivial acceptance. 
	if(dis == 0)
	{
		retval.r = r * absbright;
		retval.g = g * absbright;
		retval.b = b * absbright;
		retval.a = a * absbright;
		return retval;
	}
	appb = absbright/Sqr(dis);

	//Step 2.
	retval.r = Blend(r,vert.r);
	retval.g = Blend(r,vert.g);
	retval.b = Blend(r,vert.b);
	retval.a = 1;
	//No alpha light, sorry.

	//Set 3.
	retval.r *= appb;
	retval.g *= appb;
	retval.b *= appb;

	return retval;
}

//This is the color blend,
//Returns the blended value of c1 and c2.

float c4Light::Blend(float c1, float c2)
{
	return c1+c2;
}

c4Light::c4Light(float lum, float size)
{
	c4Light::size = size;
	absbright = lum;
	on = true;
}


void c4Light::Switch(bool flip)
{
	on = !on;
}
